set terminal postscript enhanced color
set output 'tf.ps'
reset

wrap(x) = ((x+180) - floor((x+180)/360)*360) - 180
todb(x) = 20*log10(x)
fromdb(x) = 10**(x/20.)

clp(f,f0) = 1/(1+{0,1}*f/f0)
lp(f,f0) = 1/sqrt(1+f**2/f0**2)

deg(x)=180/pi*arg(x)


f(x) = todb(abs(clp(x,f0)*c))
c = 1
f0 = 77e3
fit [:100e3] f(x) "S001.DAT" using 1:2 via f0, c

FSR = 3e8/(2*203e-3)


set title 'Power modulation transfer function from upstream to downstream of the reference cavity'

set multiplot layout 2,1
set format x "%.0s%c"
set lmargin 10
set rmargin 3
set logscale x
set ytics 20
set xtics 10
set mxtics 10
set mytics 2
set grid ytics xtics mxtics mytics
set ylabel "magnitude (dB)"
set key left bottom 
set style data lines

set xrange [1e3:1e5]

plot \
   'S001.DAT' u 1:2 title 'measurement', \
	f(x) title sprintf('fit (f0 = %.0f Hz, F = %.0f, FSR = %.0f MHz)', f0, FSR/(2*f0), FSR/1e6)


set notitle
set ytics 90
set mytics 2
set grid ytics xtics mxtics
set xlabel "frequency (Hz)"
set ylabel "phase (deg)"
unset key

plot \
   'S002.DAT' u 1:2, \
	deg(clp(x,f0)) title 'fit'
	
unset multiplot

system('epstopdf --autorotate=All tf.ps')